@@ -268,7 +268,7 @@ def _toDict(rec):
 def printRecord(rec):
     pprint.pprint(rec)
 
-def query(clauses, datasets=[], offset=0, limit=10000, fields=[], asArrays=False):
+def query(clauses, datasets=[], offset=0, limit=10000, fields=[], asArrays=False, returnPartialResults=False):
     """Provide a dict as the query, a list of collection names, and optional offset, limit, and list of fields to be returned. Returns a list of record dicts."""
         
     # TODO: change to using objectQueryByName
@@ -283,12 +283,12 @@ def query(clauses, datasets=[], offset=0, limit=10000, fields=[], asArrays=False
         'returnValuesAsArraysWithType': asArrays
     }
 
-    results = _getQueryClient().objectQuery(auth, json.dumps(q))
+    results = _getQueryClient().objectQuery(auth, json.dumps(q), returnPartialResults)
     for ds in results:
         ds.records = map(_toDict, ds.records)
     return results
 
-def luceneQuery(queryString, datasets=[], auths=[], numRecords=1000, offset=0, fields=[]):
+def luceneQuery(queryString, datasets=[], auths=[], numRecords=1000, offset=0, fields=[], returnPartialResults=False):
 
     # 1:security.TAuthInfo auth,
     # 2:string query,
@@ -303,7 +303,7 @@ def luceneQuery(queryString, datasets=[], auths=[], numRecords=1000, offset=0, f
     # TODO: add thrift method for querying via lucene by dataset name
     ids = [_getCollClient().getCollectionByName(auth, c).id for c in datasets]
 
-    results = _getQueryClient().luceneQuery(auth, queryString, ids, auths, numRecords, offset, fields, False, 0)
+    results = _getQueryClient().luceneQuery(auth, queryString, ids, auths, numRecords, offset, fields, False, 0, returnPartialResults)
     for ds in results:
         ds.records = map(_toDict, ds.records)
     return results
